# coding: utf-8
import pprint
import six
from enum import Enum



class Space:

    swagger_types = {
    
        'account': 'Account',
        'active': 'bool',
        'active_or_restricted_active': 'bool',
        'created_by': 'int',
        'created_on': 'datetime',
        'database': 'TenantDatabase',
        'deleted_by': 'int',
        'deleted_on': 'datetime',
        'id': 'int',
        'last_modified_date': 'datetime',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'postal_address': 'SpaceAddress',
        'primary_currency': 'str',
        'request_limit': 'int',
        'restricted_active': 'bool',
        'state': 'CreationEntityState',
        'technical_contact_addresses': 'list[str]',
        'time_zone': 'str',
        'version': 'int',
    }

    attribute_map = {
        'account': 'account','active': 'active','active_or_restricted_active': 'activeOrRestrictedActive','created_by': 'createdBy','created_on': 'createdOn','database': 'database','deleted_by': 'deletedBy','deleted_on': 'deletedOn','id': 'id','last_modified_date': 'lastModifiedDate','name': 'name','planned_purge_date': 'plannedPurgeDate','postal_address': 'postalAddress','primary_currency': 'primaryCurrency','request_limit': 'requestLimit','restricted_active': 'restrictedActive','state': 'state','technical_contact_addresses': 'technicalContactAddresses','time_zone': 'timeZone','version': 'version',
    }

    
    _account = None
    _active = None
    _active_or_restricted_active = None
    _created_by = None
    _created_on = None
    _database = None
    _deleted_by = None
    _deleted_on = None
    _id = None
    _last_modified_date = None
    _name = None
    _planned_purge_date = None
    _postal_address = None
    _primary_currency = None
    _request_limit = None
    _restricted_active = None
    _state = None
    _technical_contact_addresses = None
    _time_zone = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.account = kwargs.get('account', None)
        self.active = kwargs.get('active', None)
        self.active_or_restricted_active = kwargs.get('active_or_restricted_active', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.database = kwargs.get('database', None)
        self.deleted_by = kwargs.get('deleted_by', None)
        self.deleted_on = kwargs.get('deleted_on', None)
        self.id = kwargs.get('id', None)
        self.last_modified_date = kwargs.get('last_modified_date', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.postal_address = kwargs.get('postal_address', None)
        self.primary_currency = kwargs.get('primary_currency', None)
        self.request_limit = kwargs.get('request_limit', None)
        self.restricted_active = kwargs.get('restricted_active', None)
        self.state = kwargs.get('state', None)
        self.technical_contact_addresses = kwargs.get('technical_contact_addresses', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def account(self):
        """Gets the account of this Space.

            The account to which the space belongs to.

        :return: The account of this Space.
        :rtype: Account
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Space.

            The account to which the space belongs to.

        :param account: The account of this Space.
        :type: Account
        """

        self._account = account
    
    @property
    def active(self):
        """Gets the active of this Space.

            Active means that this account and all accounts in the hierarchy are active.

        :return: The active of this Space.
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Space.

            Active means that this account and all accounts in the hierarchy are active.

        :param active: The active of this Space.
        :type: bool
        """

        self._active = active
    
    @property
    def active_or_restricted_active(self):
        """Gets the active_or_restricted_active of this Space.

            This property is true when all accounts in the hierarchy are active or restricted active.

        :return: The active_or_restricted_active of this Space.
        :rtype: bool
        """
        return self._active_or_restricted_active

    @active_or_restricted_active.setter
    def active_or_restricted_active(self, active_or_restricted_active):
        """Sets the active_or_restricted_active of this Space.

            This property is true when all accounts in the hierarchy are active or restricted active.

        :param active_or_restricted_active: The active_or_restricted_active of this Space.
        :type: bool
        """

        self._active_or_restricted_active = active_or_restricted_active
    
    @property
    def created_by(self):
        """Gets the created_by of this Space.

            The ID of the user who created this entity.

        :return: The created_by of this Space.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Space.

            The ID of the user who created this entity.

        :param created_by: The created_by of this Space.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this Space.

            The date and time when this entity was created.

        :return: The created_on of this Space.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this Space.

            The date and time when this entity was created.

        :param created_on: The created_on of this Space.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def database(self):
        """Gets the database of this Space.

            The database in which the space's data are stored in.

        :return: The database of this Space.
        :rtype: TenantDatabase
        """
        return self._database

    @database.setter
    def database(self, database):
        """Sets the database of this Space.

            The database in which the space's data are stored in.

        :param database: The database of this Space.
        :type: TenantDatabase
        """

        self._database = database
    
    @property
    def deleted_by(self):
        """Gets the deleted_by of this Space.

            The ID of a user that deleted this entity.

        :return: The deleted_by of this Space.
        :rtype: int
        """
        return self._deleted_by

    @deleted_by.setter
    def deleted_by(self, deleted_by):
        """Sets the deleted_by of this Space.

            The ID of a user that deleted this entity.

        :param deleted_by: The deleted_by of this Space.
        :type: int
        """

        self._deleted_by = deleted_by
    
    @property
    def deleted_on(self):
        """Gets the deleted_on of this Space.

            The date and time when this entity was deleted.

        :return: The deleted_on of this Space.
        :rtype: datetime
        """
        return self._deleted_on

    @deleted_on.setter
    def deleted_on(self, deleted_on):
        """Sets the deleted_on of this Space.

            The date and time when this entity was deleted.

        :param deleted_on: The deleted_on of this Space.
        :type: datetime
        """

        self._deleted_on = deleted_on
    
    @property
    def id(self):
        """Gets the id of this Space.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this Space.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Space.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this Space.
        :type: int
        """

        self._id = id
    
    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this Space.

            

        :return: The last_modified_date of this Space.
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this Space.

            

        :param last_modified_date: The last_modified_date of this Space.
        :type: datetime
        """

        self._last_modified_date = last_modified_date
    
    @property
    def name(self):
        """Gets the name of this Space.

            The space name is used internally to identify the space in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this Space.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Space.

            The space name is used internally to identify the space in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this Space.
        :type: str
        """
        if name is not None and len(name) > 200:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `200`")
        if name is not None and len(name) < 3:
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `3`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Space.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this Space.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Space.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this Space.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def postal_address(self):
        """Gets the postal_address of this Space.

            The address to use in communication with clients for example in email, documents etc.

        :return: The postal_address of this Space.
        :rtype: SpaceAddress
        """
        return self._postal_address

    @postal_address.setter
    def postal_address(self, postal_address):
        """Sets the postal_address of this Space.

            The address to use in communication with clients for example in email, documents etc.

        :param postal_address: The postal_address of this Space.
        :type: SpaceAddress
        """

        self._postal_address = postal_address
    
    @property
    def primary_currency(self):
        """Gets the primary_currency of this Space.

            This is the currency that is used to display aggregated amounts in the space.

        :return: The primary_currency of this Space.
        :rtype: str
        """
        return self._primary_currency

    @primary_currency.setter
    def primary_currency(self, primary_currency):
        """Sets the primary_currency of this Space.

            This is the currency that is used to display aggregated amounts in the space.

        :param primary_currency: The primary_currency of this Space.
        :type: str
        """

        self._primary_currency = primary_currency
    
    @property
    def request_limit(self):
        """Gets the request_limit of this Space.

            The request limit defines the maximum number of API request accepted within 2 minutes for this space. This limit can only be changed with special privileges.

        :return: The request_limit of this Space.
        :rtype: int
        """
        return self._request_limit

    @request_limit.setter
    def request_limit(self, request_limit):
        """Sets the request_limit of this Space.

            The request limit defines the maximum number of API request accepted within 2 minutes for this space. This limit can only be changed with special privileges.

        :param request_limit: The request_limit of this Space.
        :type: int
        """

        self._request_limit = request_limit
    
    @property
    def restricted_active(self):
        """Gets the restricted_active of this Space.

            Restricted active means that at least one account in the hierarchy is only restricted active, but all are either restricted active or active.

        :return: The restricted_active of this Space.
        :rtype: bool
        """
        return self._restricted_active

    @restricted_active.setter
    def restricted_active(self, restricted_active):
        """Sets the restricted_active of this Space.

            Restricted active means that at least one account in the hierarchy is only restricted active, but all are either restricted active or active.

        :param restricted_active: The restricted_active of this Space.
        :type: bool
        """

        self._restricted_active = restricted_active
    
    @property
    def state(self):
        """Gets the state of this Space.

            

        :return: The state of this Space.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Space.

            

        :param state: The state of this Space.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def technical_contact_addresses(self):
        """Gets the technical_contact_addresses of this Space.

            The email address provided as contact addresses will be informed about technical issues or errors triggered by the space.

        :return: The technical_contact_addresses of this Space.
        :rtype: list[str]
        """
        return self._technical_contact_addresses

    @technical_contact_addresses.setter
    def technical_contact_addresses(self, technical_contact_addresses):
        """Sets the technical_contact_addresses of this Space.

            The email address provided as contact addresses will be informed about technical issues or errors triggered by the space.

        :param technical_contact_addresses: The technical_contact_addresses of this Space.
        :type: list[str]
        """

        self._technical_contact_addresses = technical_contact_addresses
    
    @property
    def time_zone(self):
        """Gets the time_zone of this Space.

            The time zone assigned to the space determines the time offset for calculating dates within the space. This is typically used for background processed which needs to be triggered on a specific hour within the day. Changing the space time zone will not change the display of dates.

        :return: The time_zone of this Space.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this Space.

            The time zone assigned to the space determines the time offset for calculating dates within the space. This is typically used for background processed which needs to be triggered on a specific hour within the day. Changing the space time zone will not change the display of dates.

        :param time_zone: The time_zone of this Space.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def version(self):
        """Gets the version of this Space.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this Space.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Space.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this Space.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Space, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Space):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class RestAddressFormatField(Enum):
    
    GIVEN_NAME = "GIVEN_NAME"
    FAMILY_NAME = "FAMILY_NAME"
    ORGANIZATION_NAME = "ORGANIZATION_NAME"
    STREET = "STREET"
    DEPENDENT_LOCALITY = "DEPENDENT_LOCALITY"
    CITY = "CITY"
    POSTAL_STATE = "POSTAL_STATE"
    POST_CODE = "POST_CODE"
    SORTING_CODE = "SORTING_CODE"
    COUNTRY = "COUNTRY"




# coding: utf-8
import pprint
import six
from enum import Enum



class DatabaseTranslatedStringCreate:

    swagger_types = {
    
        'items': 'list[DatabaseTranslatedStringItemCreate]',
    }

    attribute_map = {
        'items': 'items',
    }

    
    _items = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.items = kwargs.get('items', None)
        

    
    @property
    def items(self):
        """Gets the items of this DatabaseTranslatedStringCreate.

            

        :return: The items of this DatabaseTranslatedStringCreate.
        :rtype: list[DatabaseTranslatedStringItemCreate]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this DatabaseTranslatedStringCreate.

            

        :param items: The items of this DatabaseTranslatedStringCreate.
        :type: list[DatabaseTranslatedStringItemCreate]
        """

        self._items = items
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DatabaseTranslatedStringCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DatabaseTranslatedStringCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class AbstractSubscriptionProductActive:

    swagger_types = {
    
        'allowed_payment_method_configurations': 'list[int]',
        'failed_payment_suspension_period': 'str',
        'name': 'str',
        'product_locked': 'bool',
        'sort_order': 'int',
        'state': 'SubscriptionProductState',
    }

    attribute_map = {
        'allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','failed_payment_suspension_period': 'failedPaymentSuspensionPeriod','name': 'name','product_locked': 'productLocked','sort_order': 'sortOrder','state': 'state',
    }

    
    _allowed_payment_method_configurations = None
    _failed_payment_suspension_period = None
    _name = None
    _product_locked = None
    _sort_order = None
    _state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.failed_payment_suspension_period = kwargs.get('failed_payment_suspension_period', None)
        self.name = kwargs.get('name', None)
        self.product_locked = kwargs.get('product_locked', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.state = kwargs.get('state', None)
        

    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this AbstractSubscriptionProductActive.

            The allowed payment method configurations control which payment methods can be used with this product. When none is selected all methods will be allowed.

        :return: The allowed_payment_method_configurations of this AbstractSubscriptionProductActive.
        :rtype: list[int]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this AbstractSubscriptionProductActive.

            The allowed payment method configurations control which payment methods can be used with this product. When none is selected all methods will be allowed.

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this AbstractSubscriptionProductActive.
        :type: list[int]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def failed_payment_suspension_period(self):
        """Gets the failed_payment_suspension_period of this AbstractSubscriptionProductActive.

            When a payment fails, the subscription to which the payment belongs to will be suspended. When the suspension is not removed within the specified period the subscription will be terminated. A payment is considered as failed when the subscriber issues a refund or when a subscription charge fails.

        :return: The failed_payment_suspension_period of this AbstractSubscriptionProductActive.
        :rtype: str
        """
        return self._failed_payment_suspension_period

    @failed_payment_suspension_period.setter
    def failed_payment_suspension_period(self, failed_payment_suspension_period):
        """Sets the failed_payment_suspension_period of this AbstractSubscriptionProductActive.

            When a payment fails, the subscription to which the payment belongs to will be suspended. When the suspension is not removed within the specified period the subscription will be terminated. A payment is considered as failed when the subscriber issues a refund or when a subscription charge fails.

        :param failed_payment_suspension_period: The failed_payment_suspension_period of this AbstractSubscriptionProductActive.
        :type: str
        """

        self._failed_payment_suspension_period = failed_payment_suspension_period
    
    @property
    def name(self):
        """Gets the name of this AbstractSubscriptionProductActive.

            The product name is used internally to identify the configuration in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this AbstractSubscriptionProductActive.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AbstractSubscriptionProductActive.

            The product name is used internally to identify the configuration in administrative interfaces. For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this AbstractSubscriptionProductActive.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def product_locked(self):
        """Gets the product_locked of this AbstractSubscriptionProductActive.

            Marks the product as locked. Meaning that customer can not change away from this product or change to this product later on.

        :return: The product_locked of this AbstractSubscriptionProductActive.
        :rtype: bool
        """
        return self._product_locked

    @product_locked.setter
    def product_locked(self, product_locked):
        """Sets the product_locked of this AbstractSubscriptionProductActive.

            Marks the product as locked. Meaning that customer can not change away from this product or change to this product later on.

        :param product_locked: The product_locked of this AbstractSubscriptionProductActive.
        :type: bool
        """

        self._product_locked = product_locked
    
    @property
    def sort_order(self):
        """Gets the sort_order of this AbstractSubscriptionProductActive.

            The sort order controls in which order the product is listed. The sort order is used to order the products in ascending order.

        :return: The sort_order of this AbstractSubscriptionProductActive.
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this AbstractSubscriptionProductActive.

            The sort order controls in which order the product is listed. The sort order is used to order the products in ascending order.

        :param sort_order: The sort_order of this AbstractSubscriptionProductActive.
        :type: int
        """

        self._sort_order = sort_order
    
    @property
    def state(self):
        """Gets the state of this AbstractSubscriptionProductActive.

            

        :return: The state of this AbstractSubscriptionProductActive.
        :rtype: SubscriptionProductState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AbstractSubscriptionProductActive.

            

        :param state: The state of this AbstractSubscriptionProductActive.
        :type: SubscriptionProductState
        """

        self._state = state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AbstractSubscriptionProductActive, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AbstractSubscriptionProductActive):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class InstallmentPaymentSliceState(Enum):
    
    CREATE = "CREATE"
    SCHEDULED = "SCHEDULED"
    CANCELED = "CANCELED"
    PREPARE_PROCESSING = "PREPARE_PROCESSING"
    PROCESSING = "PROCESSING"
    FAILED = "FAILED"
    SUCCESSFUL = "SUCCESSFUL"




# coding: utf-8
from enum import Enum, unique


@unique
class RecurringIndicator(Enum):
    
    REGULAR_TRANSACTION = "REGULAR_TRANSACTION"
    INITIAL_RECURRING_TRANSACTION = "INITIAL_RECURRING_TRANSACTION"
    MERCHANT_INITIATED_RECURRING_TRANSACTION = "MERCHANT_INITIATED_RECURRING_TRANSACTION"
    CUSTOMER_INITIATED_RECURRING_TRANSACTION = "CUSTOMER_INITIATED_RECURRING_TRANSACTION"




# coding: utf-8
import pprint
import six
from enum import Enum



class RestAddressFormat:

    swagger_types = {
    
        'post_code_examples': 'list[str]',
        'post_code_regex': 'str',
        'required_fields': 'list[RestAddressFormatField]',
        'used_fields': 'list[RestAddressFormatField]',
    }

    attribute_map = {
        'post_code_examples': 'postCodeExamples','post_code_regex': 'postCodeRegex','required_fields': 'requiredFields','used_fields': 'usedFields',
    }

    
    _post_code_examples = None
    _post_code_regex = None
    _required_fields = None
    _used_fields = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.post_code_examples = kwargs.get('post_code_examples', None)
        self.post_code_regex = kwargs.get('post_code_regex', None)
        self.required_fields = kwargs.get('required_fields', None)
        self.used_fields = kwargs.get('used_fields', None)
        

    
    @property
    def post_code_examples(self):
        """Gets the post_code_examples of this RestAddressFormat.

            The example post codes allow the user to understand what we expect here.

        :return: The post_code_examples of this RestAddressFormat.
        :rtype: list[str]
        """
        return self._post_code_examples

    @post_code_examples.setter
    def post_code_examples(self, post_code_examples):
        """Sets the post_code_examples of this RestAddressFormat.

            The example post codes allow the user to understand what we expect here.

        :param post_code_examples: The post_code_examples of this RestAddressFormat.
        :type: list[str]
        """

        self._post_code_examples = post_code_examples
    
    @property
    def post_code_regex(self):
        """Gets the post_code_regex of this RestAddressFormat.

            The post code regex is a regular expression which can validates the input of the post code.

        :return: The post_code_regex of this RestAddressFormat.
        :rtype: str
        """
        return self._post_code_regex

    @post_code_regex.setter
    def post_code_regex(self, post_code_regex):
        """Sets the post_code_regex of this RestAddressFormat.

            The post code regex is a regular expression which can validates the input of the post code.

        :param post_code_regex: The post_code_regex of this RestAddressFormat.
        :type: str
        """

        self._post_code_regex = post_code_regex
    
    @property
    def required_fields(self):
        """Gets the required_fields of this RestAddressFormat.

            The required fields indicate what fields are required within an address to comply with the address format.

        :return: The required_fields of this RestAddressFormat.
        :rtype: list[RestAddressFormatField]
        """
        return self._required_fields

    @required_fields.setter
    def required_fields(self, required_fields):
        """Sets the required_fields of this RestAddressFormat.

            The required fields indicate what fields are required within an address to comply with the address format.

        :param required_fields: The required_fields of this RestAddressFormat.
        :type: list[RestAddressFormatField]
        """

        self._required_fields = required_fields
    
    @property
    def used_fields(self):
        """Gets the used_fields of this RestAddressFormat.

            The used fields indicate what fields are used within this address format.

        :return: The used_fields of this RestAddressFormat.
        :rtype: list[RestAddressFormatField]
        """
        return self._used_fields

    @used_fields.setter
    def used_fields(self, used_fields):
        """Sets the used_fields of this RestAddressFormat.

            The used fields indicate what fields are used within this address format.

        :param used_fields: The used_fields of this RestAddressFormat.
        :type: list[RestAddressFormatField]
        """

        self._used_fields = used_fields
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(RestAddressFormat, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, RestAddressFormat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

import six

from wallee.api_client import ApiClient

class TokenServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def check_token_creation_possible(self, space_id, transaction_id, **kwargs):
        """Check If Token Creation Is Possible

        This operation checks if the given transaction can be used to create a token out of it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_token_creation_possible(space_id, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int transaction_id: The id of the transaction for which we want to check if the token can be created or not. (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.check_token_creation_possible_with_http_info(space_id, transaction_id, **kwargs)
        else:
            (data) = self.check_token_creation_possible_with_http_info(space_id, transaction_id, **kwargs)
            return data

    def check_token_creation_possible_with_http_info(self, space_id, transaction_id, **kwargs):
        """Check If Token Creation Is Possible

        This operation checks if the given transaction can be used to create a token out of it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.check_token_creation_possible_with_http_info(space_id, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int transaction_id: The id of the transaction for which we want to check if the token can be created or not. (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'transaction_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method check_token_creation_possible" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `check_token_creation_possible`")
        # verify the required parameter 'transaction_id' is set
        if ('transaction_id' not in params or
                params['transaction_id'] is None):
            raise ValueError("Missing the required parameter `transaction_id` when calling `check_token_creation_possible`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'transaction_id' in params:
            query_params.append(('transactionId', params['transaction_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/check-token-creation-possible', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def count(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.count_with_http_info(space_id, **kwargs)
        else:
            (data) = self.count_with_http_info(space_id, **kwargs)
            return data

    def count_with_http_info(self, space_id, **kwargs):
        """Count

        Counts the number of items in the database as restricted by the given filter.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_with_http_info(space_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQueryFilter filter: The filter which restricts the entities which are used to calculate the count.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'filter']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `count`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'filter' in params:
            body_params = params['filter']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/count', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create(self, space_id, entity, **kwargs):
        """Create

        Creates the entity with the given properties.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TokenCreate entity: The token object with the properties which should be created. (required)
        :return: Token
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.create_with_http_info(space_id, entity, **kwargs)
        else:
            (data) = self.create_with_http_info(space_id, entity, **kwargs)
            return data

    def create_with_http_info(self, space_id, entity, **kwargs):
        """Create

        Creates the entity with the given properties.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_with_http_info(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TokenCreate entity: The token object with the properties which should be created. (required)
        :return: Token
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'entity']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `create`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params or
                params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `create`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'entity' in params:
            body_params = params['entity']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/create', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Token',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_token_based_on_transaction(self, space_id, transaction_id, **kwargs):
        """Create Token Based On Transaction

        This operation creates a token for the given transaction and fills it with the stored payment information of the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_token_based_on_transaction(space_id, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int transaction_id: The id of the transaction for which we want to create the token. (required)
        :return: TokenVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.create_token_based_on_transaction_with_http_info(space_id, transaction_id, **kwargs)
        else:
            (data) = self.create_token_based_on_transaction_with_http_info(space_id, transaction_id, **kwargs)
            return data

    def create_token_based_on_transaction_with_http_info(self, space_id, transaction_id, **kwargs):
        """Create Token Based On Transaction

        This operation creates a token for the given transaction and fills it with the stored payment information of the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_token_based_on_transaction_with_http_info(space_id, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int transaction_id: The id of the transaction for which we want to create the token. (required)
        :return: TokenVersion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'transaction_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_token_based_on_transaction" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `create_token_based_on_transaction`")
        # verify the required parameter 'transaction_id' is set
        if ('transaction_id' not in params or
                params['transaction_id'] is None):
            raise ValueError("Missing the required parameter `transaction_id` when calling `create_token_based_on_transaction`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'transaction_id' in params:
            query_params.append(('transactionId', params['transaction_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/create-token-based-on-transaction', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TokenVersion',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_transaction_for_token_update(self, space_id, token_id, **kwargs):
        """Create Transaction for Token Update

        This operation creates a transaction which allows the updating of the provided token.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_transaction_for_token_update(space_id, token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int token_id: The id of the token which should be updated. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.create_transaction_for_token_update_with_http_info(space_id, token_id, **kwargs)
        else:
            (data) = self.create_transaction_for_token_update_with_http_info(space_id, token_id, **kwargs)
            return data

    def create_transaction_for_token_update_with_http_info(self, space_id, token_id, **kwargs):
        """Create Transaction for Token Update

        This operation creates a transaction which allows the updating of the provided token.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_transaction_for_token_update_with_http_info(space_id, token_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int token_id: The id of the token which should be updated. (required)
        :return: Transaction
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'token_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_transaction_for_token_update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `create_transaction_for_token_update`")
        # verify the required parameter 'token_id' is set
        if ('token_id' not in params or
                params['token_id'] is None):
            raise ValueError("Missing the required parameter `token_id` when calling `create_transaction_for_token_update`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'token_id' in params:
            query_params.append(('tokenId', params['token_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/createTransactionForTokenUpdate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Transaction',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete(self, space_id, id, **kwargs):
        """Delete

        Deletes the entity with the given id.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.delete_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.delete_with_http_info(space_id, id, **kwargs)
            return data

    def delete_with_http_info(self, space_id, id, **kwargs):
        """Delete

        Deletes the entity with the given id.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id:  (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `delete`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'id' in params:
            body_params = params['id']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def process_transaction(self, space_id, transaction_id, **kwargs):
        """Process Transaction

        This operation processes the given transaction by using the token associated with the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_transaction(space_id, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int transaction_id: The id of the transaction for which we want to check if the token can be created or not. (required)
        :return: Charge
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.process_transaction_with_http_info(space_id, transaction_id, **kwargs)
        else:
            (data) = self.process_transaction_with_http_info(space_id, transaction_id, **kwargs)
            return data

    def process_transaction_with_http_info(self, space_id, transaction_id, **kwargs):
        """Process Transaction

        This operation processes the given transaction by using the token associated with the transaction.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.process_transaction_with_http_info(space_id, transaction_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int transaction_id: The id of the transaction for which we want to check if the token can be created or not. (required)
        :return: Charge
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'transaction_id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method process_transaction" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `process_transaction`")
        # verify the required parameter 'transaction_id' is set
        if ('transaction_id' not in params or
                params['transaction_id'] is None):
            raise ValueError("Missing the required parameter `transaction_id` when calling `process_transaction`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'transaction_id' in params:
            query_params.append(('transactionId', params['transaction_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/process-transaction', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Charge',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def read(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the token which should be returned. (required)
        :return: Token
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.read_with_http_info(space_id, id, **kwargs)
        else:
            (data) = self.read_with_http_info(space_id, id, **kwargs)
            return data

    def read_with_http_info(self, space_id, id, **kwargs):
        """Read

        Reads the entity with the given 'id' and returns it.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.read_with_http_info(space_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param int id: The id of the token which should be returned. (required)
        :return: Token
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method read" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `read`")
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `read`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/read', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Token',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the tokens which are returned by the search. (required)
        :return: list[Token]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.search_with_http_info(space_id, query, **kwargs)
        else:
            (data) = self.search_with_http_info(space_id, query, **kwargs)
            return data

    def search_with_http_info(self, space_id, query, **kwargs):
        """Search

        Searches for the entities as specified by the given query.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_with_http_info(space_id, query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param EntityQuery query: The query restricts the tokens which are returned by the search. (required)
        :return: list[Token]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'query']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `search`")
        # verify the required parameter 'query' is set
        if ('query' not in params or
                params['query'] is None):
            raise ValueError("Missing the required parameter `query` when calling `search`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query' in params:
            body_params = params['query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Token]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update(self, space_id, entity, **kwargs):
        """Update

        This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TokenUpdate entity: The object with all the properties which should be updated. The id and the version are required properties. (required)
        :return: Token
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.update_with_http_info(space_id, entity, **kwargs)
        else:
            (data) = self.update_with_http_info(space_id, entity, **kwargs)
            return data

    def update_with_http_info(self, space_id, entity, **kwargs):
        """Update

        This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_with_http_info(space_id, entity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param TokenUpdate entity: The object with all the properties which should be updated. The id and the version are required properties. (required)
        :return: Token
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'entity']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `update`")
        # verify the required parameter 'entity' is set
        if ('entity' not in params or
                params['entity'] is None):
            raise ValueError("Missing the required parameter `entity` when calling `update`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'entity' in params:
            body_params = params['entity']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/token/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Token',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8
from enum import Enum, unique


@unique
class TransactionInvoiceState(Enum):
    
    CREATE = "CREATE"
    OPEN = "OPEN"
    OVERDUE = "OVERDUE"
    CANCELED = "CANCELED"
    PAID = "PAID"
    DERECOGNIZED = "DERECOGNIZED"
    NOT_APPLICABLE = "NOT_APPLICABLE"




# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentTerminalConfigurationVersion:

    swagger_types = {
    
        'configuration': 'PaymentTerminalConfiguration',
        'connector_configurations': 'list[int]',
        'created_by': 'int',
        'created_on': 'datetime',
        'default_currency': 'str',
        'id': 'int',
        'linked_space_id': 'int',
        'maintenance_window_duration': 'str',
        'maintenance_window_start': 'str',
        'planned_purge_date': 'datetime',
        'state': 'PaymentTerminalConfigurationVersionState',
        'time_zone': 'str',
        'version': 'int',
        'version_applied_immediately': 'bool',
    }

    attribute_map = {
        'configuration': 'configuration','connector_configurations': 'connectorConfigurations','created_by': 'createdBy','created_on': 'createdOn','default_currency': 'defaultCurrency','id': 'id','linked_space_id': 'linkedSpaceId','maintenance_window_duration': 'maintenanceWindowDuration','maintenance_window_start': 'maintenanceWindowStart','planned_purge_date': 'plannedPurgeDate','state': 'state','time_zone': 'timeZone','version': 'version','version_applied_immediately': 'versionAppliedImmediately',
    }

    
    _configuration = None
    _connector_configurations = None
    _created_by = None
    _created_on = None
    _default_currency = None
    _id = None
    _linked_space_id = None
    _maintenance_window_duration = None
    _maintenance_window_start = None
    _planned_purge_date = None
    _state = None
    _time_zone = None
    _version = None
    _version_applied_immediately = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.configuration = kwargs.get('configuration', None)
        self.connector_configurations = kwargs.get('connector_configurations', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.default_currency = kwargs.get('default_currency', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.maintenance_window_duration = kwargs.get('maintenance_window_duration', None)
        self.maintenance_window_start = kwargs.get('maintenance_window_start', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.version = kwargs.get('version', None)
        self.version_applied_immediately = kwargs.get('version_applied_immediately', None)
        

    
    @property
    def configuration(self):
        """Gets the configuration of this PaymentTerminalConfigurationVersion.

            

        :return: The configuration of this PaymentTerminalConfigurationVersion.
        :rtype: PaymentTerminalConfiguration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this PaymentTerminalConfigurationVersion.

            

        :param configuration: The configuration of this PaymentTerminalConfigurationVersion.
        :type: PaymentTerminalConfiguration
        """

        self._configuration = configuration
    
    @property
    def connector_configurations(self):
        """Gets the connector_configurations of this PaymentTerminalConfigurationVersion.

            

        :return: The connector_configurations of this PaymentTerminalConfigurationVersion.
        :rtype: list[int]
        """
        return self._connector_configurations

    @connector_configurations.setter
    def connector_configurations(self, connector_configurations):
        """Sets the connector_configurations of this PaymentTerminalConfigurationVersion.

            

        :param connector_configurations: The connector_configurations of this PaymentTerminalConfigurationVersion.
        :type: list[int]
        """

        self._connector_configurations = connector_configurations
    
    @property
    def created_by(self):
        """Gets the created_by of this PaymentTerminalConfigurationVersion.

            

        :return: The created_by of this PaymentTerminalConfigurationVersion.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this PaymentTerminalConfigurationVersion.

            

        :param created_by: The created_by of this PaymentTerminalConfigurationVersion.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this PaymentTerminalConfigurationVersion.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this PaymentTerminalConfigurationVersion.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this PaymentTerminalConfigurationVersion.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this PaymentTerminalConfigurationVersion.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def default_currency(self):
        """Gets the default_currency of this PaymentTerminalConfigurationVersion.

            The currency is derived by default from the terminal location. By setting a specific currency the derived currency is overridden.

        :return: The default_currency of this PaymentTerminalConfigurationVersion.
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this PaymentTerminalConfigurationVersion.

            The currency is derived by default from the terminal location. By setting a specific currency the derived currency is overridden.

        :param default_currency: The default_currency of this PaymentTerminalConfigurationVersion.
        :type: str
        """

        self._default_currency = default_currency
    
    @property
    def id(self):
        """Gets the id of this PaymentTerminalConfigurationVersion.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this PaymentTerminalConfigurationVersion.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentTerminalConfigurationVersion.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this PaymentTerminalConfigurationVersion.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentTerminalConfigurationVersion.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this PaymentTerminalConfigurationVersion.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentTerminalConfigurationVersion.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this PaymentTerminalConfigurationVersion.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def maintenance_window_duration(self):
        """Gets the maintenance_window_duration of this PaymentTerminalConfigurationVersion.

            

        :return: The maintenance_window_duration of this PaymentTerminalConfigurationVersion.
        :rtype: str
        """
        return self._maintenance_window_duration

    @maintenance_window_duration.setter
    def maintenance_window_duration(self, maintenance_window_duration):
        """Sets the maintenance_window_duration of this PaymentTerminalConfigurationVersion.

            

        :param maintenance_window_duration: The maintenance_window_duration of this PaymentTerminalConfigurationVersion.
        :type: str
        """

        self._maintenance_window_duration = maintenance_window_duration
    
    @property
    def maintenance_window_start(self):
        """Gets the maintenance_window_start of this PaymentTerminalConfigurationVersion.

            

        :return: The maintenance_window_start of this PaymentTerminalConfigurationVersion.
        :rtype: str
        """
        return self._maintenance_window_start

    @maintenance_window_start.setter
    def maintenance_window_start(self, maintenance_window_start):
        """Sets the maintenance_window_start of this PaymentTerminalConfigurationVersion.

            

        :param maintenance_window_start: The maintenance_window_start of this PaymentTerminalConfigurationVersion.
        :type: str
        """

        self._maintenance_window_start = maintenance_window_start
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentTerminalConfigurationVersion.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this PaymentTerminalConfigurationVersion.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentTerminalConfigurationVersion.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentTerminalConfigurationVersion.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this PaymentTerminalConfigurationVersion.

            

        :return: The state of this PaymentTerminalConfigurationVersion.
        :rtype: PaymentTerminalConfigurationVersionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentTerminalConfigurationVersion.

            

        :param state: The state of this PaymentTerminalConfigurationVersion.
        :type: PaymentTerminalConfigurationVersionState
        """

        self._state = state
    
    @property
    def time_zone(self):
        """Gets the time_zone of this PaymentTerminalConfigurationVersion.

            

        :return: The time_zone of this PaymentTerminalConfigurationVersion.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this PaymentTerminalConfigurationVersion.

            

        :param time_zone: The time_zone of this PaymentTerminalConfigurationVersion.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def version(self):
        """Gets the version of this PaymentTerminalConfigurationVersion.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this PaymentTerminalConfigurationVersion.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentTerminalConfigurationVersion.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this PaymentTerminalConfigurationVersion.
        :type: int
        """

        self._version = version
    
    @property
    def version_applied_immediately(self):
        """Gets the version_applied_immediately of this PaymentTerminalConfigurationVersion.

            

        :return: The version_applied_immediately of this PaymentTerminalConfigurationVersion.
        :rtype: bool
        """
        return self._version_applied_immediately

    @version_applied_immediately.setter
    def version_applied_immediately(self, version_applied_immediately):
        """Sets the version_applied_immediately of this PaymentTerminalConfigurationVersion.

            

        :param version_applied_immediately: The version_applied_immediately of this PaymentTerminalConfigurationVersion.
        :type: bool
        """

        self._version_applied_immediately = version_applied_immediately
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentTerminalConfigurationVersion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentTerminalConfigurationVersion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ProductPeriodFeeUpdate:

    swagger_types = {
    
        'id': 'int',
        'version': 'int',
        'component': 'int',
        'description': 'DatabaseTranslatedStringCreate',
        'ledger_entry_title': 'DatabaseTranslatedStringCreate',
        'name': 'DatabaseTranslatedStringCreate',
        'number_of_free_trial_periods': 'int',
        'period_fee': 'list[PersistableCurrencyAmountUpdate]',
    }

    attribute_map = {
        'id': 'id','version': 'version','component': 'component','description': 'description','ledger_entry_title': 'ledgerEntryTitle','name': 'name','number_of_free_trial_periods': 'numberOfFreeTrialPeriods','period_fee': 'periodFee',
    }

    
    _id = None
    _version = None
    _component = None
    _description = None
    _ledger_entry_title = None
    _name = None
    _number_of_free_trial_periods = None
    _period_fee = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id')

        self.version = kwargs.get('version')

        self.component = kwargs.get('component', None)
        self.description = kwargs.get('description', None)
        self.ledger_entry_title = kwargs.get('ledger_entry_title', None)
        self.name = kwargs.get('name', None)
        self.number_of_free_trial_periods = kwargs.get('number_of_free_trial_periods', None)
        self.period_fee = kwargs.get('period_fee', None)
        

    
    @property
    def id(self):
        """Gets the id of this ProductPeriodFeeUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this ProductPeriodFeeUpdate.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProductPeriodFeeUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this ProductPeriodFeeUpdate.
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id
    
    @property
    def version(self):
        """Gets the version of this ProductPeriodFeeUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this ProductPeriodFeeUpdate.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ProductPeriodFeeUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this ProductPeriodFeeUpdate.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version
    
    @property
    def component(self):
        """Gets the component of this ProductPeriodFeeUpdate.

            

        :return: The component of this ProductPeriodFeeUpdate.
        :rtype: int
        """
        return self._component

    @component.setter
    def component(self, component):
        """Sets the component of this ProductPeriodFeeUpdate.

            

        :param component: The component of this ProductPeriodFeeUpdate.
        :type: int
        """

        self._component = component
    
    @property
    def description(self):
        """Gets the description of this ProductPeriodFeeUpdate.

            The description of a component fee describes the fee to the subscriber. The description may be shown in documents or on certain user interfaces.

        :return: The description of this ProductPeriodFeeUpdate.
        :rtype: DatabaseTranslatedStringCreate
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProductPeriodFeeUpdate.

            The description of a component fee describes the fee to the subscriber. The description may be shown in documents or on certain user interfaces.

        :param description: The description of this ProductPeriodFeeUpdate.
        :type: DatabaseTranslatedStringCreate
        """

        self._description = description
    
    @property
    def ledger_entry_title(self):
        """Gets the ledger_entry_title of this ProductPeriodFeeUpdate.

            The ledger entry title will be used for the title in the ledger entry and in the invoice.

        :return: The ledger_entry_title of this ProductPeriodFeeUpdate.
        :rtype: DatabaseTranslatedStringCreate
        """
        return self._ledger_entry_title

    @ledger_entry_title.setter
    def ledger_entry_title(self, ledger_entry_title):
        """Sets the ledger_entry_title of this ProductPeriodFeeUpdate.

            The ledger entry title will be used for the title in the ledger entry and in the invoice.

        :param ledger_entry_title: The ledger_entry_title of this ProductPeriodFeeUpdate.
        :type: DatabaseTranslatedStringCreate
        """

        self._ledger_entry_title = ledger_entry_title
    
    @property
    def name(self):
        """Gets the name of this ProductPeriodFeeUpdate.

            The name of the fee should describe for the subscriber in few words for what the fee is for.

        :return: The name of this ProductPeriodFeeUpdate.
        :rtype: DatabaseTranslatedStringCreate
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProductPeriodFeeUpdate.

            The name of the fee should describe for the subscriber in few words for what the fee is for.

        :param name: The name of this ProductPeriodFeeUpdate.
        :type: DatabaseTranslatedStringCreate
        """

        self._name = name
    
    @property
    def number_of_free_trial_periods(self):
        """Gets the number_of_free_trial_periods of this ProductPeriodFeeUpdate.

            The number of free trial periods specify how many periods are free of charge at the begining of the subscription.

        :return: The number_of_free_trial_periods of this ProductPeriodFeeUpdate.
        :rtype: int
        """
        return self._number_of_free_trial_periods

    @number_of_free_trial_periods.setter
    def number_of_free_trial_periods(self, number_of_free_trial_periods):
        """Sets the number_of_free_trial_periods of this ProductPeriodFeeUpdate.

            The number of free trial periods specify how many periods are free of charge at the begining of the subscription.

        :param number_of_free_trial_periods: The number_of_free_trial_periods of this ProductPeriodFeeUpdate.
        :type: int
        """

        self._number_of_free_trial_periods = number_of_free_trial_periods
    
    @property
    def period_fee(self):
        """Gets the period_fee of this ProductPeriodFeeUpdate.

            The period fee is charged for every period of the subscription except for those periods which are trial periods.

        :return: The period_fee of this ProductPeriodFeeUpdate.
        :rtype: list[PersistableCurrencyAmountUpdate]
        """
        return self._period_fee

    @period_fee.setter
    def period_fee(self, period_fee):
        """Sets the period_fee of this ProductPeriodFeeUpdate.

            The period fee is charged for every period of the subscription except for those periods which are trial periods.

        :param period_fee: The period_fee of this ProductPeriodFeeUpdate.
        :type: list[PersistableCurrencyAmountUpdate]
        """

        self._period_fee = period_fee
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ProductPeriodFeeUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ProductPeriodFeeUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionMetricUsageReport:

    swagger_types = {
    
        'consumed_units': 'float',
        'created_by_user_id': 'int',
        'created_on': 'datetime',
        'description': 'str',
        'external_id': 'str',
        'id': 'int',
        'linked_space_id': 'int',
        'metric': 'int',
        'planned_purge_date': 'datetime',
        'subscription': 'int',
        'version': 'int',
    }

    attribute_map = {
        'consumed_units': 'consumedUnits','created_by_user_id': 'createdByUserId','created_on': 'createdOn','description': 'description','external_id': 'externalId','id': 'id','linked_space_id': 'linkedSpaceId','metric': 'metric','planned_purge_date': 'plannedPurgeDate','subscription': 'subscription','version': 'version',
    }

    
    _consumed_units = None
    _created_by_user_id = None
    _created_on = None
    _description = None
    _external_id = None
    _id = None
    _linked_space_id = None
    _metric = None
    _planned_purge_date = None
    _subscription = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.consumed_units = kwargs.get('consumed_units', None)
        self.created_by_user_id = kwargs.get('created_by_user_id', None)
        self.created_on = kwargs.get('created_on', None)
        self.description = kwargs.get('description', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.metric = kwargs.get('metric', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.subscription = kwargs.get('subscription', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def consumed_units(self):
        """Gets the consumed_units of this SubscriptionMetricUsageReport.

            The consumed units describe the amount of resources consumed. Those consumed units will be billed in the next billing cycle.

        :return: The consumed_units of this SubscriptionMetricUsageReport.
        :rtype: float
        """
        return self._consumed_units

    @consumed_units.setter
    def consumed_units(self, consumed_units):
        """Sets the consumed_units of this SubscriptionMetricUsageReport.

            The consumed units describe the amount of resources consumed. Those consumed units will be billed in the next billing cycle.

        :param consumed_units: The consumed_units of this SubscriptionMetricUsageReport.
        :type: float
        """

        self._consumed_units = consumed_units
    
    @property
    def created_by_user_id(self):
        """Gets the created_by_user_id of this SubscriptionMetricUsageReport.

            

        :return: The created_by_user_id of this SubscriptionMetricUsageReport.
        :rtype: int
        """
        return self._created_by_user_id

    @created_by_user_id.setter
    def created_by_user_id(self, created_by_user_id):
        """Sets the created_by_user_id of this SubscriptionMetricUsageReport.

            

        :param created_by_user_id: The created_by_user_id of this SubscriptionMetricUsageReport.
        :type: int
        """

        self._created_by_user_id = created_by_user_id
    
    @property
    def created_on(self):
        """Gets the created_on of this SubscriptionMetricUsageReport.

            

        :return: The created_on of this SubscriptionMetricUsageReport.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SubscriptionMetricUsageReport.

            

        :param created_on: The created_on of this SubscriptionMetricUsageReport.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def description(self):
        """Gets the description of this SubscriptionMetricUsageReport.

            The metric usage report description describe the reported usage. This description may be shown to the end user.

        :return: The description of this SubscriptionMetricUsageReport.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SubscriptionMetricUsageReport.

            The metric usage report description describe the reported usage. This description may be shown to the end user.

        :param description: The description of this SubscriptionMetricUsageReport.
        :type: str
        """
        if description is not None and len(description) > 100:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `100`")

        self._description = description
    
    @property
    def external_id(self):
        """Gets the external_id of this SubscriptionMetricUsageReport.

            The external id identifies the metric usage uniquely.

        :return: The external_id of this SubscriptionMetricUsageReport.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this SubscriptionMetricUsageReport.

            The external id identifies the metric usage uniquely.

        :param external_id: The external_id of this SubscriptionMetricUsageReport.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this SubscriptionMetricUsageReport.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this SubscriptionMetricUsageReport.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionMetricUsageReport.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this SubscriptionMetricUsageReport.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionMetricUsageReport.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this SubscriptionMetricUsageReport.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionMetricUsageReport.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionMetricUsageReport.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def metric(self):
        """Gets the metric of this SubscriptionMetricUsageReport.

            The metric usage report is linked to the metric for which the usage should be recorded.

        :return: The metric of this SubscriptionMetricUsageReport.
        :rtype: int
        """
        return self._metric

    @metric.setter
    def metric(self, metric):
        """Sets the metric of this SubscriptionMetricUsageReport.

            The metric usage report is linked to the metric for which the usage should be recorded.

        :param metric: The metric of this SubscriptionMetricUsageReport.
        :type: int
        """

        self._metric = metric
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SubscriptionMetricUsageReport.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this SubscriptionMetricUsageReport.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SubscriptionMetricUsageReport.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this SubscriptionMetricUsageReport.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def subscription(self):
        """Gets the subscription of this SubscriptionMetricUsageReport.

            The subscription to which the usage is added to.

        :return: The subscription of this SubscriptionMetricUsageReport.
        :rtype: int
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this SubscriptionMetricUsageReport.

            The subscription to which the usage is added to.

        :param subscription: The subscription of this SubscriptionMetricUsageReport.
        :type: int
        """

        self._subscription = subscription
    
    @property
    def version(self):
        """Gets the version of this SubscriptionMetricUsageReport.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this SubscriptionMetricUsageReport.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionMetricUsageReport.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this SubscriptionMetricUsageReport.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionMetricUsageReport, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionMetricUsageReport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriberCreation:

    swagger_types = {
    
        'email_address': 'str',
        'phone_number': 'str',
        'shopify_customer_id': 'str',
    }

    attribute_map = {
        'email_address': 'emailAddress','phone_number': 'phoneNumber','shopify_customer_id': 'shopifyCustomerId',
    }

    
    _email_address = None
    _phone_number = None
    _shopify_customer_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.email_address = kwargs.get('email_address', None)
        self.phone_number = kwargs.get('phone_number', None)
        self.shopify_customer_id = kwargs.get('shopify_customer_id')

        

    
    @property
    def email_address(self):
        """Gets the email_address of this ShopifySubscriberCreation.

            

        :return: The email_address of this ShopifySubscriberCreation.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this ShopifySubscriberCreation.

            

        :param email_address: The email_address of this ShopifySubscriberCreation.
        :type: str
        """

        self._email_address = email_address
    
    @property
    def phone_number(self):
        """Gets the phone_number of this ShopifySubscriberCreation.

            

        :return: The phone_number of this ShopifySubscriberCreation.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this ShopifySubscriberCreation.

            

        :param phone_number: The phone_number of this ShopifySubscriberCreation.
        :type: str
        """

        self._phone_number = phone_number
    
    @property
    def shopify_customer_id(self):
        """Gets the shopify_customer_id of this ShopifySubscriberCreation.

            The customer ID has to correspond to the ID assigned to the customer by Shopify. When the subscriber already exists no new subscriber will be created.

        :return: The shopify_customer_id of this ShopifySubscriberCreation.
        :rtype: str
        """
        return self._shopify_customer_id

    @shopify_customer_id.setter
    def shopify_customer_id(self, shopify_customer_id):
        """Sets the shopify_customer_id of this ShopifySubscriberCreation.

            The customer ID has to correspond to the ID assigned to the customer by Shopify. When the subscriber already exists no new subscriber will be created.

        :param shopify_customer_id: The shopify_customer_id of this ShopifySubscriberCreation.
        :type: str
        """
        if shopify_customer_id is None:
            raise ValueError("Invalid value for `shopify_customer_id`, must not be `None`")

        self._shopify_customer_id = shopify_customer_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriberCreation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriberCreation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class DatabaseTranslatedStringItem:

    swagger_types = {
    
        'language': 'str',
        'language_code': 'str',
        'translation': 'str',
    }

    attribute_map = {
        'language': 'language','language_code': 'languageCode','translation': 'translation',
    }

    
    _language = None
    _language_code = None
    _translation = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.language = kwargs.get('language', None)
        self.language_code = kwargs.get('language_code', None)
        self.translation = kwargs.get('translation', None)
        

    
    @property
    def language(self):
        """Gets the language of this DatabaseTranslatedStringItem.

            

        :return: The language of this DatabaseTranslatedStringItem.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this DatabaseTranslatedStringItem.

            

        :param language: The language of this DatabaseTranslatedStringItem.
        :type: str
        """

        self._language = language
    
    @property
    def language_code(self):
        """Gets the language_code of this DatabaseTranslatedStringItem.

            

        :return: The language_code of this DatabaseTranslatedStringItem.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """Sets the language_code of this DatabaseTranslatedStringItem.

            

        :param language_code: The language_code of this DatabaseTranslatedStringItem.
        :type: str
        """

        self._language_code = language_code
    
    @property
    def translation(self):
        """Gets the translation of this DatabaseTranslatedStringItem.

            

        :return: The translation of this DatabaseTranslatedStringItem.
        :rtype: str
        """
        return self._translation

    @translation.setter
    def translation(self, translation):
        """Sets the translation of this DatabaseTranslatedStringItem.

            

        :param translation: The translation of this DatabaseTranslatedStringItem.
        :type: str
        """
        if translation is not None and len(translation) > 16777216:
            raise ValueError("Invalid value for `translation`, length must be less than or equal to `16777216`")

        self._translation = translation
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DatabaseTranslatedStringItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DatabaseTranslatedStringItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class ShopifySubscriptionWeekday(Enum):
    
    MONDAY = "MONDAY"
    TUESDAY = "TUESDAY"
    WEDNESDAY = "WEDNESDAY"
    THURSDAY = "THURSDAY"
    FRIDAY = "FRIDAY"
    SATURDAY = "SATURDAY"
    SUNDAY = "SUNDAY"




# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionMetric:

    swagger_types = {
    
        'description': 'DatabaseTranslatedString',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'DatabaseTranslatedString',
        'planned_purge_date': 'datetime',
        'state': 'CreationEntityState',
        'type': 'SubscriptionMetricType',
        'version': 'int',
    }

    attribute_map = {
        'description': 'description','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','planned_purge_date': 'plannedPurgeDate','state': 'state','type': 'type','version': 'version',
    }

    
    _description = None
    _id = None
    _linked_space_id = None
    _name = None
    _planned_purge_date = None
    _state = None
    _type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.description = kwargs.get('description', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.type = kwargs.get('type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def description(self):
        """Gets the description of this SubscriptionMetric.

            

        :return: The description of this SubscriptionMetric.
        :rtype: DatabaseTranslatedString
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SubscriptionMetric.

            

        :param description: The description of this SubscriptionMetric.
        :type: DatabaseTranslatedString
        """

        self._description = description
    
    @property
    def id(self):
        """Gets the id of this SubscriptionMetric.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this SubscriptionMetric.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionMetric.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this SubscriptionMetric.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionMetric.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this SubscriptionMetric.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionMetric.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionMetric.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this SubscriptionMetric.

            

        :return: The name of this SubscriptionMetric.
        :rtype: DatabaseTranslatedString
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubscriptionMetric.

            

        :param name: The name of this SubscriptionMetric.
        :type: DatabaseTranslatedString
        """

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SubscriptionMetric.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this SubscriptionMetric.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SubscriptionMetric.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this SubscriptionMetric.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this SubscriptionMetric.

            

        :return: The state of this SubscriptionMetric.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionMetric.

            

        :param state: The state of this SubscriptionMetric.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def type(self):
        """Gets the type of this SubscriptionMetric.

            

        :return: The type of this SubscriptionMetric.
        :rtype: SubscriptionMetricType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SubscriptionMetric.

            

        :param type: The type of this SubscriptionMetric.
        :type: SubscriptionMetricType
        """

        self._type = type
    
    @property
    def version(self):
        """Gets the version of this SubscriptionMetric.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this SubscriptionMetric.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionMetric.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this SubscriptionMetric.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionMetric, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionMetric):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class Subscription:

    swagger_types = {
    
        'activated_on': 'datetime',
        'affiliate': 'SubscriptionAffiliate',
        'created_on': 'datetime',
        'current_product_version': 'SubscriptionProductVersion',
        'description': 'str',
        'id': 'int',
        'initialized_on': 'datetime',
        'language': 'str',
        'linked_space_id': 'int',
        'planned_purge_date': 'datetime',
        'planned_termination_date': 'datetime',
        'reference': 'str',
        'state': 'SubscriptionState',
        'subscriber': 'Subscriber',
        'terminated_by': 'int',
        'terminated_on': 'datetime',
        'terminating_on': 'datetime',
        'termination_scheduled_on': 'datetime',
        'token': 'Token',
        'version': 'int',
    }

    attribute_map = {
        'activated_on': 'activatedOn','affiliate': 'affiliate','created_on': 'createdOn','current_product_version': 'currentProductVersion','description': 'description','id': 'id','initialized_on': 'initializedOn','language': 'language','linked_space_id': 'linkedSpaceId','planned_purge_date': 'plannedPurgeDate','planned_termination_date': 'plannedTerminationDate','reference': 'reference','state': 'state','subscriber': 'subscriber','terminated_by': 'terminatedBy','terminated_on': 'terminatedOn','terminating_on': 'terminatingOn','termination_scheduled_on': 'terminationScheduledOn','token': 'token','version': 'version',
    }

    
    _activated_on = None
    _affiliate = None
    _created_on = None
    _current_product_version = None
    _description = None
    _id = None
    _initialized_on = None
    _language = None
    _linked_space_id = None
    _planned_purge_date = None
    _planned_termination_date = None
    _reference = None
    _state = None
    _subscriber = None
    _terminated_by = None
    _terminated_on = None
    _terminating_on = None
    _termination_scheduled_on = None
    _token = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.activated_on = kwargs.get('activated_on', None)
        self.affiliate = kwargs.get('affiliate', None)
        self.created_on = kwargs.get('created_on', None)
        self.current_product_version = kwargs.get('current_product_version', None)
        self.description = kwargs.get('description', None)
        self.id = kwargs.get('id', None)
        self.initialized_on = kwargs.get('initialized_on', None)
        self.language = kwargs.get('language', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.planned_termination_date = kwargs.get('planned_termination_date', None)
        self.reference = kwargs.get('reference', None)
        self.state = kwargs.get('state', None)
        self.subscriber = kwargs.get('subscriber', None)
        self.terminated_by = kwargs.get('terminated_by', None)
        self.terminated_on = kwargs.get('terminated_on', None)
        self.terminating_on = kwargs.get('terminating_on', None)
        self.termination_scheduled_on = kwargs.get('termination_scheduled_on', None)
        self.token = kwargs.get('token', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def activated_on(self):
        """Gets the activated_on of this Subscription.

            

        :return: The activated_on of this Subscription.
        :rtype: datetime
        """
        return self._activated_on

    @activated_on.setter
    def activated_on(self, activated_on):
        """Sets the activated_on of this Subscription.

            

        :param activated_on: The activated_on of this Subscription.
        :type: datetime
        """

        self._activated_on = activated_on
    
    @property
    def affiliate(self):
        """Gets the affiliate of this Subscription.

            

        :return: The affiliate of this Subscription.
        :rtype: SubscriptionAffiliate
        """
        return self._affiliate

    @affiliate.setter
    def affiliate(self, affiliate):
        """Sets the affiliate of this Subscription.

            

        :param affiliate: The affiliate of this Subscription.
        :type: SubscriptionAffiliate
        """

        self._affiliate = affiliate
    
    @property
    def created_on(self):
        """Gets the created_on of this Subscription.

            

        :return: The created_on of this Subscription.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this Subscription.

            

        :param created_on: The created_on of this Subscription.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def current_product_version(self):
        """Gets the current_product_version of this Subscription.

            

        :return: The current_product_version of this Subscription.
        :rtype: SubscriptionProductVersion
        """
        return self._current_product_version

    @current_product_version.setter
    def current_product_version(self, current_product_version):
        """Sets the current_product_version of this Subscription.

            

        :param current_product_version: The current_product_version of this Subscription.
        :type: SubscriptionProductVersion
        """

        self._current_product_version = current_product_version
    
    @property
    def description(self):
        """Gets the description of this Subscription.

            

        :return: The description of this Subscription.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Subscription.

            

        :param description: The description of this Subscription.
        :type: str
        """
        if description is not None and len(description) > 200:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `200`")

        self._description = description
    
    @property
    def id(self):
        """Gets the id of this Subscription.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this Subscription.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Subscription.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this Subscription.
        :type: int
        """

        self._id = id
    
    @property
    def initialized_on(self):
        """Gets the initialized_on of this Subscription.

            

        :return: The initialized_on of this Subscription.
        :rtype: datetime
        """
        return self._initialized_on

    @initialized_on.setter
    def initialized_on(self, initialized_on):
        """Sets the initialized_on of this Subscription.

            

        :param initialized_on: The initialized_on of this Subscription.
        :type: datetime
        """

        self._initialized_on = initialized_on
    
    @property
    def language(self):
        """Gets the language of this Subscription.

            

        :return: The language of this Subscription.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Subscription.

            

        :param language: The language of this Subscription.
        :type: str
        """

        self._language = language
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this Subscription.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this Subscription.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this Subscription.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this Subscription.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Subscription.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this Subscription.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Subscription.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this Subscription.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def planned_termination_date(self):
        """Gets the planned_termination_date of this Subscription.

            

        :return: The planned_termination_date of this Subscription.
        :rtype: datetime
        """
        return self._planned_termination_date

    @planned_termination_date.setter
    def planned_termination_date(self, planned_termination_date):
        """Sets the planned_termination_date of this Subscription.

            

        :param planned_termination_date: The planned_termination_date of this Subscription.
        :type: datetime
        """

        self._planned_termination_date = planned_termination_date
    
    @property
    def reference(self):
        """Gets the reference of this Subscription.

            

        :return: The reference of this Subscription.
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this Subscription.

            

        :param reference: The reference of this Subscription.
        :type: str
        """
        if reference is not None and len(reference) > 100:
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `100`")

        self._reference = reference
    
    @property
    def state(self):
        """Gets the state of this Subscription.

            

        :return: The state of this Subscription.
        :rtype: SubscriptionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Subscription.

            

        :param state: The state of this Subscription.
        :type: SubscriptionState
        """

        self._state = state
    
    @property
    def subscriber(self):
        """Gets the subscriber of this Subscription.

            

        :return: The subscriber of this Subscription.
        :rtype: Subscriber
        """
        return self._subscriber

    @subscriber.setter
    def subscriber(self, subscriber):
        """Sets the subscriber of this Subscription.

            

        :param subscriber: The subscriber of this Subscription.
        :type: Subscriber
        """

        self._subscriber = subscriber
    
    @property
    def terminated_by(self):
        """Gets the terminated_by of this Subscription.

            

        :return: The terminated_by of this Subscription.
        :rtype: int
        """
        return self._terminated_by

    @terminated_by.setter
    def terminated_by(self, terminated_by):
        """Sets the terminated_by of this Subscription.

            

        :param terminated_by: The terminated_by of this Subscription.
        :type: int
        """

        self._terminated_by = terminated_by
    
    @property
    def terminated_on(self):
        """Gets the terminated_on of this Subscription.

            

        :return: The terminated_on of this Subscription.
        :rtype: datetime
        """
        return self._terminated_on

    @terminated_on.setter
    def terminated_on(self, terminated_on):
        """Sets the terminated_on of this Subscription.

            

        :param terminated_on: The terminated_on of this Subscription.
        :type: datetime
        """

        self._terminated_on = terminated_on
    
    @property
    def terminating_on(self):
        """Gets the terminating_on of this Subscription.

            

        :return: The terminating_on of this Subscription.
        :rtype: datetime
        """
        return self._terminating_on

    @terminating_on.setter
    def terminating_on(self, terminating_on):
        """Sets the terminating_on of this Subscription.

            

        :param terminating_on: The terminating_on of this Subscription.
        :type: datetime
        """

        self._terminating_on = terminating_on
    
    @property
    def termination_scheduled_on(self):
        """Gets the termination_scheduled_on of this Subscription.

            

        :return: The termination_scheduled_on of this Subscription.
        :rtype: datetime
        """
        return self._termination_scheduled_on

    @termination_scheduled_on.setter
    def termination_scheduled_on(self, termination_scheduled_on):
        """Sets the termination_scheduled_on of this Subscription.

            

        :param termination_scheduled_on: The termination_scheduled_on of this Subscription.
        :type: datetime
        """

        self._termination_scheduled_on = termination_scheduled_on
    
    @property
    def token(self):
        """Gets the token of this Subscription.

            

        :return: The token of this Subscription.
        :rtype: Token
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this Subscription.

            

        :param token: The token of this Subscription.
        :type: Token
        """

        self._token = token
    
    @property
    def version(self):
        """Gets the version of this Subscription.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this Subscription.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Subscription.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this Subscription.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Subscription, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Subscription):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionSuspension:

    swagger_types = {
    
        'created_on': 'datetime',
        'effective_end_date': 'datetime',
        'end_action': 'SubscriptionSuspensionAction',
        'id': 'int',
        'language': 'str',
        'linked_space_id': 'int',
        'note': 'str',
        'period_bill': 'int',
        'planned_end_date': 'datetime',
        'planned_purge_date': 'datetime',
        'reason': 'SubscriptionSuspensionReason',
        'state': 'SubscriptionSuspensionState',
        'subscription': 'int',
        'version': 'int',
    }

    attribute_map = {
        'created_on': 'createdOn','effective_end_date': 'effectiveEndDate','end_action': 'endAction','id': 'id','language': 'language','linked_space_id': 'linkedSpaceId','note': 'note','period_bill': 'periodBill','planned_end_date': 'plannedEndDate','planned_purge_date': 'plannedPurgeDate','reason': 'reason','state': 'state','subscription': 'subscription','version': 'version',
    }

    
    _created_on = None
    _effective_end_date = None
    _end_action = None
    _id = None
    _language = None
    _linked_space_id = None
    _note = None
    _period_bill = None
    _planned_end_date = None
    _planned_purge_date = None
    _reason = None
    _state = None
    _subscription = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.effective_end_date = kwargs.get('effective_end_date', None)
        self.end_action = kwargs.get('end_action', None)
        self.id = kwargs.get('id', None)
        self.language = kwargs.get('language', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.note = kwargs.get('note', None)
        self.period_bill = kwargs.get('period_bill', None)
        self.planned_end_date = kwargs.get('planned_end_date', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.reason = kwargs.get('reason', None)
        self.state = kwargs.get('state', None)
        self.subscription = kwargs.get('subscription', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def created_on(self):
        """Gets the created_on of this SubscriptionSuspension.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this SubscriptionSuspension.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SubscriptionSuspension.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this SubscriptionSuspension.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def effective_end_date(self):
        """Gets the effective_end_date of this SubscriptionSuspension.

            

        :return: The effective_end_date of this SubscriptionSuspension.
        :rtype: datetime
        """
        return self._effective_end_date

    @effective_end_date.setter
    def effective_end_date(self, effective_end_date):
        """Sets the effective_end_date of this SubscriptionSuspension.

            

        :param effective_end_date: The effective_end_date of this SubscriptionSuspension.
        :type: datetime
        """

        self._effective_end_date = effective_end_date
    
    @property
    def end_action(self):
        """Gets the end_action of this SubscriptionSuspension.

            When the suspension reaches the planned end date the end action will be carried out. This action is only executed when the suspension is ended automatically based on the end date.

        :return: The end_action of this SubscriptionSuspension.
        :rtype: SubscriptionSuspensionAction
        """
        return self._end_action

    @end_action.setter
    def end_action(self, end_action):
        """Sets the end_action of this SubscriptionSuspension.

            When the suspension reaches the planned end date the end action will be carried out. This action is only executed when the suspension is ended automatically based on the end date.

        :param end_action: The end_action of this SubscriptionSuspension.
        :type: SubscriptionSuspensionAction
        """

        self._end_action = end_action
    
    @property
    def id(self):
        """Gets the id of this SubscriptionSuspension.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this SubscriptionSuspension.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionSuspension.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this SubscriptionSuspension.
        :type: int
        """

        self._id = id
    
    @property
    def language(self):
        """Gets the language of this SubscriptionSuspension.

            

        :return: The language of this SubscriptionSuspension.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this SubscriptionSuspension.

            

        :param language: The language of this SubscriptionSuspension.
        :type: str
        """

        self._language = language
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionSuspension.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this SubscriptionSuspension.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionSuspension.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionSuspension.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def note(self):
        """Gets the note of this SubscriptionSuspension.

            The note may contain some internal information for the suspension. The note will not be disclosed to the subscriber.

        :return: The note of this SubscriptionSuspension.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this SubscriptionSuspension.

            The note may contain some internal information for the suspension. The note will not be disclosed to the subscriber.

        :param note: The note of this SubscriptionSuspension.
        :type: str
        """
        if note is not None and len(note) > 300:
            raise ValueError("Invalid value for `note`, length must be less than or equal to `300`")

        self._note = note
    
    @property
    def period_bill(self):
        """Gets the period_bill of this SubscriptionSuspension.

            

        :return: The period_bill of this SubscriptionSuspension.
        :rtype: int
        """
        return self._period_bill

    @period_bill.setter
    def period_bill(self, period_bill):
        """Sets the period_bill of this SubscriptionSuspension.

            

        :param period_bill: The period_bill of this SubscriptionSuspension.
        :type: int
        """

        self._period_bill = period_bill
    
    @property
    def planned_end_date(self):
        """Gets the planned_end_date of this SubscriptionSuspension.

            The planned end date of the suspension identifies the date on which the suspension will be ended automatically.

        :return: The planned_end_date of this SubscriptionSuspension.
        :rtype: datetime
        """
        return self._planned_end_date

    @planned_end_date.setter
    def planned_end_date(self, planned_end_date):
        """Sets the planned_end_date of this SubscriptionSuspension.

            The planned end date of the suspension identifies the date on which the suspension will be ended automatically.

        :param planned_end_date: The planned_end_date of this SubscriptionSuspension.
        :type: datetime
        """

        self._planned_end_date = planned_end_date
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this SubscriptionSuspension.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this SubscriptionSuspension.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this SubscriptionSuspension.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this SubscriptionSuspension.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def reason(self):
        """Gets the reason of this SubscriptionSuspension.

            The suspension reason indicates why a suspension has been created.

        :return: The reason of this SubscriptionSuspension.
        :rtype: SubscriptionSuspensionReason
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this SubscriptionSuspension.

            The suspension reason indicates why a suspension has been created.

        :param reason: The reason of this SubscriptionSuspension.
        :type: SubscriptionSuspensionReason
        """

        self._reason = reason
    
    @property
    def state(self):
        """Gets the state of this SubscriptionSuspension.

            

        :return: The state of this SubscriptionSuspension.
        :rtype: SubscriptionSuspensionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionSuspension.

            

        :param state: The state of this SubscriptionSuspension.
        :type: SubscriptionSuspensionState
        """

        self._state = state
    
    @property
    def subscription(self):
        """Gets the subscription of this SubscriptionSuspension.

            

        :return: The subscription of this SubscriptionSuspension.
        :rtype: int
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this SubscriptionSuspension.

            

        :param subscription: The subscription of this SubscriptionSuspension.
        :type: int
        """

        self._subscription = subscription
    
    @property
    def version(self):
        """Gets the version of this SubscriptionSuspension.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this SubscriptionSuspension.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionSuspension.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this SubscriptionSuspension.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionSuspension, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionSuspension):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class User:

    swagger_types = {
    
        'id': 'int',
        'planned_purge_date': 'datetime',
        'scope': 'Scope',
        'state': 'CreationEntityState',
        'user_type': 'UserType',
        'version': 'int',
    }

    attribute_map = {
        'id': 'id','planned_purge_date': 'plannedPurgeDate','scope': 'scope','state': 'state','user_type': 'userType','version': 'version',
    }

    
    _id = None
    _planned_purge_date = None
    _scope = None
    _state = None
    _user_type = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.scope = kwargs.get('scope', None)
        self.state = kwargs.get('state', None)
        self.user_type = kwargs.get('user_type', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def id(self):
        """Gets the id of this User.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this User.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this User.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this User.
        :type: int
        """

        self._id = id
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this User.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this User.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this User.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this User.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def scope(self):
        """Gets the scope of this User.

            

        :return: The scope of this User.
        :rtype: Scope
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this User.

            

        :param scope: The scope of this User.
        :type: Scope
        """

        self._scope = scope
    
    @property
    def state(self):
        """Gets the state of this User.

            

        :return: The state of this User.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this User.

            

        :param state: The state of this User.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def user_type(self):
        """Gets the user_type of this User.

            

        :return: The user_type of this User.
        :rtype: UserType
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this User.

            

        :param user_type: The user_type of this User.
        :type: UserType
        """

        self._user_type = user_type
    
    @property
    def version(self):
        """Gets the version of this User.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this User.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this User.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this User.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, User):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionProductVersionRetirement:

    swagger_types = {
    
        'created_on': 'datetime',
        'id': 'int',
        'linked_space_id': 'int',
        'product_version': 'SubscriptionProductVersion',
        'respect_terminiation_periods_enabled': 'bool',
        'target_product': 'SubscriptionProduct',
        'version': 'int',
    }

    attribute_map = {
        'created_on': 'createdOn','id': 'id','linked_space_id': 'linkedSpaceId','product_version': 'productVersion','respect_terminiation_periods_enabled': 'respectTerminiationPeriodsEnabled','target_product': 'targetProduct','version': 'version',
    }

    
    _created_on = None
    _id = None
    _linked_space_id = None
    _product_version = None
    _respect_terminiation_periods_enabled = None
    _target_product = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.product_version = kwargs.get('product_version', None)
        self.respect_terminiation_periods_enabled = kwargs.get('respect_terminiation_periods_enabled', None)
        self.target_product = kwargs.get('target_product', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def created_on(self):
        """Gets the created_on of this SubscriptionProductVersionRetirement.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this SubscriptionProductVersionRetirement.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this SubscriptionProductVersionRetirement.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this SubscriptionProductVersionRetirement.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def id(self):
        """Gets the id of this SubscriptionProductVersionRetirement.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this SubscriptionProductVersionRetirement.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionProductVersionRetirement.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this SubscriptionProductVersionRetirement.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this SubscriptionProductVersionRetirement.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this SubscriptionProductVersionRetirement.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this SubscriptionProductVersionRetirement.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this SubscriptionProductVersionRetirement.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def product_version(self):
        """Gets the product_version of this SubscriptionProductVersionRetirement.

            

        :return: The product_version of this SubscriptionProductVersionRetirement.
        :rtype: SubscriptionProductVersion
        """
        return self._product_version

    @product_version.setter
    def product_version(self, product_version):
        """Sets the product_version of this SubscriptionProductVersionRetirement.

            

        :param product_version: The product_version of this SubscriptionProductVersionRetirement.
        :type: SubscriptionProductVersion
        """

        self._product_version = product_version
    
    @property
    def respect_terminiation_periods_enabled(self):
        """Gets the respect_terminiation_periods_enabled of this SubscriptionProductVersionRetirement.

            

        :return: The respect_terminiation_periods_enabled of this SubscriptionProductVersionRetirement.
        :rtype: bool
        """
        return self._respect_terminiation_periods_enabled

    @respect_terminiation_periods_enabled.setter
    def respect_terminiation_periods_enabled(self, respect_terminiation_periods_enabled):
        """Sets the respect_terminiation_periods_enabled of this SubscriptionProductVersionRetirement.

            

        :param respect_terminiation_periods_enabled: The respect_terminiation_periods_enabled of this SubscriptionProductVersionRetirement.
        :type: bool
        """

        self._respect_terminiation_periods_enabled = respect_terminiation_periods_enabled
    
    @property
    def target_product(self):
        """Gets the target_product of this SubscriptionProductVersionRetirement.

            When a target product is not chosen, all customers with the retired product will be terminated.

        :return: The target_product of this SubscriptionProductVersionRetirement.
        :rtype: SubscriptionProduct
        """
        return self._target_product

    @target_product.setter
    def target_product(self, target_product):
        """Sets the target_product of this SubscriptionProductVersionRetirement.

            When a target product is not chosen, all customers with the retired product will be terminated.

        :param target_product: The target_product of this SubscriptionProductVersionRetirement.
        :type: SubscriptionProduct
        """

        self._target_product = target_product
    
    @property
    def version(self):
        """Gets the version of this SubscriptionProductVersionRetirement.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this SubscriptionProductVersionRetirement.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionProductVersionRetirement.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this SubscriptionProductVersionRetirement.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionProductVersionRetirement, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionProductVersionRetirement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriptionUpdateRequest:

    swagger_types = {
    
        'billing_configuration': 'ShopifySubscriptionModelBillingConfiguration',
        'id': 'int',
        'items': 'list[ShopifySubscriptionModelItem]',
        'store_order_confirmation_email_enabled': 'bool',
        'subscriber_suspension_allowed': 'bool',
    }

    attribute_map = {
        'billing_configuration': 'billingConfiguration','id': 'id','items': 'items','store_order_confirmation_email_enabled': 'storeOrderConfirmationEmailEnabled','subscriber_suspension_allowed': 'subscriberSuspensionAllowed',
    }

    
    _billing_configuration = None
    _id = None
    _items = None
    _store_order_confirmation_email_enabled = None
    _subscriber_suspension_allowed = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billing_configuration = kwargs.get('billing_configuration', None)
        self.id = kwargs.get('id', None)
        self.items = kwargs.get('items', None)
        self.store_order_confirmation_email_enabled = kwargs.get('store_order_confirmation_email_enabled', None)
        self.subscriber_suspension_allowed = kwargs.get('subscriber_suspension_allowed', None)
        

    
    @property
    def billing_configuration(self):
        """Gets the billing_configuration of this ShopifySubscriptionUpdateRequest.

            

        :return: The billing_configuration of this ShopifySubscriptionUpdateRequest.
        :rtype: ShopifySubscriptionModelBillingConfiguration
        """
        return self._billing_configuration

    @billing_configuration.setter
    def billing_configuration(self, billing_configuration):
        """Sets the billing_configuration of this ShopifySubscriptionUpdateRequest.

            

        :param billing_configuration: The billing_configuration of this ShopifySubscriptionUpdateRequest.
        :type: ShopifySubscriptionModelBillingConfiguration
        """

        self._billing_configuration = billing_configuration
    
    @property
    def id(self):
        """Gets the id of this ShopifySubscriptionUpdateRequest.

            

        :return: The id of this ShopifySubscriptionUpdateRequest.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShopifySubscriptionUpdateRequest.

            

        :param id: The id of this ShopifySubscriptionUpdateRequest.
        :type: int
        """

        self._id = id
    
    @property
    def items(self):
        """Gets the items of this ShopifySubscriptionUpdateRequest.

            

        :return: The items of this ShopifySubscriptionUpdateRequest.
        :rtype: list[ShopifySubscriptionModelItem]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ShopifySubscriptionUpdateRequest.

            

        :param items: The items of this ShopifySubscriptionUpdateRequest.
        :type: list[ShopifySubscriptionModelItem]
        """

        self._items = items
    
    @property
    def store_order_confirmation_email_enabled(self):
        """Gets the store_order_confirmation_email_enabled of this ShopifySubscriptionUpdateRequest.

            

        :return: The store_order_confirmation_email_enabled of this ShopifySubscriptionUpdateRequest.
        :rtype: bool
        """
        return self._store_order_confirmation_email_enabled

    @store_order_confirmation_email_enabled.setter
    def store_order_confirmation_email_enabled(self, store_order_confirmation_email_enabled):
        """Sets the store_order_confirmation_email_enabled of this ShopifySubscriptionUpdateRequest.

            

        :param store_order_confirmation_email_enabled: The store_order_confirmation_email_enabled of this ShopifySubscriptionUpdateRequest.
        :type: bool
        """

        self._store_order_confirmation_email_enabled = store_order_confirmation_email_enabled
    
    @property
    def subscriber_suspension_allowed(self):
        """Gets the subscriber_suspension_allowed of this ShopifySubscriptionUpdateRequest.

            

        :return: The subscriber_suspension_allowed of this ShopifySubscriptionUpdateRequest.
        :rtype: bool
        """
        return self._subscriber_suspension_allowed

    @subscriber_suspension_allowed.setter
    def subscriber_suspension_allowed(self, subscriber_suspension_allowed):
        """Sets the subscriber_suspension_allowed of this ShopifySubscriptionUpdateRequest.

            

        :param subscriber_suspension_allowed: The subscriber_suspension_allowed of this ShopifySubscriptionUpdateRequest.
        :type: bool
        """

        self._subscriber_suspension_allowed = subscriber_suspension_allowed
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriptionUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriptionUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
